// ----------------------------------------------------------------------------
// Projekt       : Analytica AnaGate API
// File          : AnaGateDllSPI.h
// Author        : Axel Schmidt
// Copyright     : (C) 2005 by Analytica GmbH
// ----------------------------------------------------------------------------
// $Id: AnaGateDllSPI.h,v 1.4 2009/04/30 13:24:56 stefanwelisch Exp $
//
// $Log: AnaGateDllSPI.h,v $
// Revision 1.4  2009/04/30 13:24:56  stefanwelisch
// Referenzen als Pointer implementiert
//
// Revision 1.3  2007/05/21 11:43:39  axelschmidt
// standard timeout 500 -> 1000 ms
//
// Revision 1.2  2005/12/27 08:26:37  AxelSchmidt
// base functions of SPI interface
//
// Revision 1.1  2005/11/28 17:05:48  axelschmidt
// SPI integrated, initial version
//
// ----------------------------------------------------------------------------

#ifndef ANAGATE_DLL_SPI_H
#define ANAGATE_DLL_SPI_H

// Defines --------------------------------------------------------------------
#include <AnaGateDLL.h>

// Prototyping ----------------------------------------------------------------
extern "C"
{
   /** Opens an AnaGate SPI device.
      @param pHandle Pointer to an integer, in which the device handle is stored, if device is
                     opened successfully.
      @param pcIPAddress Tcp/ip address of the AnaGate device (Port is always 5000).
      @param nTimeout Standard tcp/ip timeout in millseconds.
      @return If the function succeeds, the return value is zero. If the function fails, the return value is non zero.
   */
   ANAGATEDLL_API AnaInt32 ANAGATEDLL_CALLING SPIOpenDevice( AnaInt32 *pHandle, const char * pcIPAddress, AnaInt32 nTimeout );

   /** Closes an open AnaGate SPI device.
       @param hHandle Device handle (from a successfull #OpenDevice call).
       @return If the function succeeds, the return value is zero. If the function fails, the return value is non zero.
   */
   ANAGATEDLL_API AnaInt32 ANAGATEDLL_CALLING SPICloseDevice( AnaInt32 hHandle );

   /** Writes data to the SPI partner The data is routed to the partner directly without any transformation,
      so the user of the interface has to build a correct data buffer.
      @param hHandle Device handle (from a successfull #OpenDevice call).
      @param pcBufWrite    Pointer to the buffer containing the data to be written.
      @param nBufWriteLen  Number of bytes to be written.
      @param pcBufRead     Pointer to the buffer that receives the data read.
      @param nBufReadLen   Number of bytes to be read (should be same as number of bytes written).
      @return. If the function succeeds, the return value is zero. If the function fails, the return value is non zero.
   */
   ANAGATEDLL_API AnaInt32 ANAGATEDLL_CALLING SPIDataReq( AnaInt32 hHandle, const char * pcBufWrite, AnaInt32 nBufWriteLen,
                                                char * pcBufRead, AnaInt32 nBufReadLen );

   /** Executes a sequence of write/read commands to the SPI partner.
      The write data is routed to the partner directly without any transformation,
      so the user of the interface has to build a correct data buffer.
      This command doesn't block until a response has been received.
      The user can wait for it by calling #SPISequenceGetCnf.
      @param hHandle Device handle (from a successfull #OpenDevice call).
      @param pcBufWrite    Pointer to the buffer containing the raw sequence data.
      @param nBufWriteLen  Number of bytes to be written.
      @param pMsgID        Pointer to variable where the ID of the sent message is stored.
      @return. If the function succeeds, the return value is zero. If the function fails, the return value is non zero.
   */
   ANAGATEDLL_API AnaInt32 ANAGATEDLL_CALLING SPISequenceReq( AnaInt32 hHandle, const char * pcBufWrite, AnaInt32 nBufWriteLen, AnaInt16 * pMsgID );

   /** Waits for a confirmation to a Sequence Request that was sent with #SPISequenceReq.
      @param hHandle       Device handle (from a successfull #OpenDevice call).
      @param nMsgID        ID of the sent message.
      @param pcBufRead     Pointer to the buffer for the received data.
      @param nBufReadLen   Number of bytes to be received (should be enough for the previously sent request).
      @return. If the function succeeds, the return value is zero. If the function fails, the return value is non zero.
   */
   ANAGATEDLL_API AnaInt32 ANAGATEDLL_CALLING SPISequenceGetCnf( AnaInt32 hHandle, AnaInt16 nMsgID, char * pcBufRead, AnaInt32 nBufReadLen );

   /** Reads data from the specified offset to a data buffer.
      @remarks This command is a specialized version of the #Read method and is optimized for SPI EEProms.
               <p>This version implicit performs a write request to set the offset where to read from and the
               following read request in a single tcpip telegramm.</p>
               <p>Use this method only for EEProm partners</p>
      @param hHandle Device handle (from a successfull #OpenDevice call).
      @param nChipAddress  Chip enable address (bit 1 - 3 of the slave address).
      @param nOffset     Offset position where data is to be read (EEProm partner).
      @param pcBuffer    Pointer to the buffer that receives the data read.
      @param nBufferLen  Number of bytes to be read.
      @param nOffsetFormat Offset format. To create a I2C command, the method must specify the offset in
                           the correct format. At this time two formats are supported (8-bit and 16bit addresses).
      @return. If the function succeeds, the return value is zero. If the function fails, the return value is non zero.
   */
   ANAGATEDLL_API AnaInt32 ANAGATEDLL_CALLING SPIErrorMessage( AnaInt32 nRC, char *pcMessage, AnaInt32 nMessageLen );

   /** Sets the global settings of an AnaGate I2C device.
       @param hHandle Device handle (from a successfull #OpenDevice call).
       @param nBaudrate Baud rate.
       @param nSigLevel Signal level.
       @param nAuxVoltage Auxiliary voltage supply.
       @param nClockMode The phase and the polarity of the clock line.
       @return If the function succeeds, the return value is zero. If the function fails, the return value is non zero.
   */
   ANAGATEDLL_API AnaInt32 ANAGATEDLL_CALLING SPISetGlobals( AnaInt32 hHandle, AnaInt32 nBaudrate, AnaUInt8 nSigLevel,
                                                             AnaUInt8 nAuxVoltage, AnaUInt8 nClockMode );
   /** Gets the global settings of an open AnaGate I2C device.
       @param hHandle Device handle (from a successfull #OpenDevice call).
       @param nBaudrate Pointer to the variable that receives Baud rate.
       @param nSigLevel Pointer to the variable that receives Signal level.
       @param nAuxVoltage Pointer to the variable that receives Auxiliary voltage supply.
       @param nClockMode Pointer to the variable that receives The phase and the polarity of the clock line.
       @return If the function succeeds, the return value is zero. If the function fails, the return value is non zero.
   */
   ANAGATEDLL_API AnaInt32 ANAGATEDLL_CALLING SPIGetGlobals( AnaInt32 hHandle, AnaInt32 * pnBaudrate, AnaUInt8 * pnSigLevel,
                                                   AnaUInt8 * pnAuxVoltage, AnaUInt8 * pnClockMode );

   /** Reads data from digital io register of the partner.
      @param hHandle Device handle (from a successfull #OpenDevice call).
      @param nInputBits   Pointer to the variable that receives the digtial input register read.
      @param nOutputBits  Pointer to the variable that receives the digtial output register read.
      @return. If the function succeeds, the return value is zero. If the function fails, the return value is non zero.
   */
   ANAGATEDLL_API AnaInt32 ANAGATEDLL_CALLING SPIReadDigital( AnaInt32 hHandle, AnaUInt32 * pnInputBits, AnaUInt32 * pnOutputBits );

   /** Writes data to digital io register of the partner.
      @param hHandle Device handle (from a successfull #OpenDevice call).
      @param nOutputBits  Refererence to the variable that hold the digtial IO output register bits to write.
      @return. If the function succeeds, the return value is zero. If the function fails, the return value is non zero.
   */
   ANAGATEDLL_API AnaInt32 ANAGATEDLL_CALLING SPIWriteDigital( AnaInt32 hHandle, AnaUInt32 nOutputBits );
}

#endif // ANAGATE_DLL_I2C_H
